==> mastapy-13.0.0.post4-py3-none-any.whl: mastapy/electric_machines/_1244.py <==
"""AbstractToothAndSlot"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar, Union, Tuple, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ABSTRACT_TOOTH_AND_SLOT = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "AbstractToothAndSlot"
)

if TYPE_CHECKING:
    from mastapy.electric_machines import _1251, _1305


__docformat__ = "restructuredtext en"
__all__ = ("AbstractToothAndSlot",)


Self = TypeVar("Self", bound="AbstractToothAndSlot")


class AbstractToothAndSlot(_0.APIBase):
    """AbstractToothAndSlot

    This is a mastapy class.
    """

    TYPE = _ABSTRACT_TOOTH_AND_SLOT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_AbstractToothAndSlot")

    class _Cast_AbstractToothAndSlot:
        """Special nested class for casting AbstractToothAndSlot to subclasses."""

        def __init__(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot",
            parent: "AbstractToothAndSlot",
        ):
            self._parent = parent

        @property
        def cad_tooth_and_slot(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot",
        ) -> "_1251.CADToothAndSlot":
            from mastapy.electric_machines import _1251

            return self._parent._cast(_1251.CADToothAndSlot)

        @property
        def tooth_and_slot(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot",
        ) -> "_1305.ToothAndSlot":
            from mastapy.electric_machines import _1305

            return self._parent._cast(_1305.ToothAndSlot)

        @property
        def abstract_tooth_and_slot(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot",
        ) -> "AbstractToothAndSlot":
            return self._parent

        def __getattr__(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "AbstractToothAndSlot.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def angle_to_centre_of_first_slot_opening(
        self: Self,
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.AngleToCentreOfFirstSlotOpening

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @angle_to_centre_of_first_slot_opening.setter
    @enforce_parameter_types
    def angle_to_centre_of_first_slot_opening(
        self: Self, value: "Union[float, Tuple[float, bool]]"
    ):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.AngleToCentreOfFirstSlotOpening = value

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: Self) -> "AbstractToothAndSlot._Cast_AbstractToothAndSlot":
        return self._Cast_AbstractToothAndSlot(self)

==> mastapy-13.0.1.post3-py3-none-any.whl: mastapy/electric_machines/_1244.py <==
"""AbstractToothAndSlot"""

from __future__ import annotations

from typing import TypeVar, Union, Tuple, List

from mastapy._internal.type_enforcement import enforce_parameter_types
from mastapy._internal.implicit import overridable
from mastapy._internal.overridable_constructor import _unpack_overridable
from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_ABSTRACT_TOOTH_AND_SLOT = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "AbstractToothAndSlot"
)


__docformat__ = "restructuredtext en"
__all__ = ("AbstractToothAndSlot",)


Self = TypeVar("Self", bound="AbstractToothAndSlot")


class AbstractToothAndSlot(_0.APIBase):
    """AbstractToothAndSlot

    This is a mastapy class.
    """

    TYPE = _ABSTRACT_TOOTH_AND_SLOT
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_AbstractToothAndSlot")

    class _Cast_AbstractToothAndSlot:
        """Special nested class for casting AbstractToothAndSlot to subclasses."""

        def __init__(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot",
            parent: "AbstractToothAndSlot",
        ):
            self._parent = parent

        @property
        def cad_tooth_and_slot(self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot"):
            from mastapy.electric_machines import _1251

            return self._parent._cast(_1251.CADToothAndSlot)

        @property
        def tooth_and_slot(self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot"):
            from mastapy.electric_machines import _1305

            return self._parent._cast(_1305.ToothAndSlot)

        @property
        def abstract_tooth_and_slot(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot",
        ) -> "AbstractToothAndSlot":
            return self._parent

        def __getattr__(
            self: "AbstractToothAndSlot._Cast_AbstractToothAndSlot", name: str
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "AbstractToothAndSlot.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def angle_to_centre_of_first_slot_opening(
        self: Self,
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.AngleToCentreOfFirstSlotOpening

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @angle_to_centre_of_first_slot_opening.setter
    @enforce_parameter_types
    def angle_to_centre_of_first_slot_opening(
        self: Self, value: "Union[float, Tuple[float, bool]]"
    ):
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.AngleToCentreOfFirstSlotOpening = value

    @property
    def report_names(self: Self) -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def output_default_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: Self, file_path: "str"):
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: Self) -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(self: Self, report_name: "str", file_path: "str"):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: Self, report_name: "str", file_path: "str"
    ):
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: Self, report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: Self) -> "AbstractToothAndSlot._Cast_AbstractToothAndSlot":
        return self._Cast_AbstractToothAndSlot(self)
